<?php

use Phoenix\Migration\AbstractMigration;

class RemoveMimeTypeEditing extends AbstractMigration
{
	protected function up(): void
	{
		$this->table(
			$this->prefix('system_mimetype')
		)->drop();
	}

	protected function down(): void
	{
		$tableName = $this->prefix('system_mimetype');

		if (!$this->tableExists($tableName)) {
			$this->table($tableName, 'mimetypeid')
				->setCharset('utf8')
				->setCollation('utf8_general_ci')
				->addColumn('mimetypeid', 'integer', ['autoincrement' => true])
				->addColumn('extension', 'string', ['default' => '', 'length' => 60])
				->addColumn('types', 'text')
				->addColumn('name', 'string', ['default' => ''])
				->addColumn('dirname', 'string')
				->create();
		}

		$this->insert(
			$tableName,
			[
				[
					'mimetypeid' => 1,
					'extension' => 'bin',
					'types' => 'application/octet-stream',
					'name' => 'Binary File/Linux Executable',
					'dirname' => '',
				],
				[
					'mimetypeid' => 2,
					'extension' => 'dms',
					'types' => 'application/octet-stream',
					'name' => 'Amiga DISKMASHER Compressed Archive',
					'dirname' => '',
				],
				[
					'mimetypeid' => 3,
					'extension' => 'class',
					'types' => 'application/octet-stream',
					'name' => 'Java Bytecode',
					'dirname' => '',
				],
				[
					'mimetypeid' => 4,
					'extension' => 'so',
					'types' => 'application/octet-stream',
					'name' => 'UNIX Shared Library Function',
					'dirname' => '',
				],
				[
					'mimetypeid' => 5,
					'extension' => 'dll',
					'types' => 'application/octet-stream',
					'name' => 'Dynamic Link Library',
					'dirname' => '',
				],
				[
					'mimetypeid' => 6,
					'extension' => 'hqx',
					'types' => 'application/binhex application/mac-binhex application/mac-binhex40',
					'name' => 'Macintosh BinHex 4 Compressed Archive',
					'dirname' => '',
				],
				[
					'mimetypeid' => 7,
					'extension' => 'cpt',
					'types' => 'application/mac-compactpro application/compact_pro',
					'name' => 'Compact Pro Archive',
					'dirname' => '',
				],
				[
					'mimetypeid' => 8,
					'extension' => 'lha',
					'types' => 'application/lha application/x-lha application/octet-stream application/x-compress application/x-compressed application/maclha',
					'name' => 'Compressed Archive File',
					'dirname' => '',
				],
				[
					'mimetypeid' => 9,
					'extension' => 'lzh',
					'types' => 'application/lzh application/x-lzh application/x-lha application/x-compress application/x-compressed application/x-lzh-archive zz-application/zz-winassoc-lzh application/maclha application/octet-stream',
					'name' => 'Compressed Archive File',
					'dirname' => '',
				],
				[
					'mimetypeid' => 10,
					'extension' => 'sh',
					'types' => 'application/x-shar',
					'name' => 'UNIX shar Archive File',
					'dirname' => '',
				],
				[
					'mimetypeid' => 11,
					'extension' => 'shar',
					'types' => 'application/x-shar',
					'name' => 'UNIX shar Archive File',
					'dirname' => '',
				],
				[
					'mimetypeid' => 12,
					'extension' => 'tar',
					'types' => 'application/tar application/x-tar applicaton/x-gtar multipart/x-tar application/x-compress application/x-compressed',
					'name' => 'Tape Archive File',
					'dirname' => '',
				],
				[
					'mimetypeid' => 13,
					'extension' => 'gtar',
					'types' => 'application/x-gtar',
					'name' => 'GNU tar Compressed File Archive',
					'dirname' => '',
				],
				[
					'mimetypeid' => 14,
					'extension' => 'ustar',
					'types' => 'application/x-ustar multipart/x-ustar',
					'name' => 'POSIX tar Compressed Archive',
					'dirname' => '',
				],
				[
					'mimetypeid' => 15,
					'extension' => 'zip',
					'types' => 'application/zip application/x-zip application/x-zip-compressed application/octet-stream application/x-compress application/x-compressed multipart/x-zip',
					'name' => 'Compressed Archive File',
					'dirname' => '',
				],
				[
					'mimetypeid' => 16,
					'extension' => 'exe',
					'types' => 'application/exe application/x-exe application/dos-exe application/x-winexe application/msdos-windows application/x-msdos-program',
					'name' => 'Executable File',
					'dirname' => '',
				],
				[
					'mimetypeid' => 17,
					'extension' => 'wmz',
					'types' => 'application/x-ms-wmz',
					'name' => 'Windows Media Compressed Skin File',
					'dirname' => '',
				],
				[
					'mimetypeid' => 18,
					'extension' => 'wmd',
					'types' => 'application/x-ms-wmd',
					'name' => 'Windows Media Download File',
					'dirname' => '',
				],
				[
					'mimetypeid' => 19,
					'extension' => 'doc',
					'types' => 'application/msword application/doc appl/text application/vnd.msword application/vnd.ms-word application/winword application/word application/x-msw6 application/x-msword',
					'name' => 'Word Document',
					'dirname' => 'system',
				],
				[
					'mimetypeid' => 20,
					'extension' => 'pdf',
					'types' => 'application/pdf application/acrobat application/x-pdf applications/vnd.pdf text/pdf',
					'name' => 'Acrobat Portable Document Format',
					'dirname' => 'system',
				],
				[
					'mimetypeid' => 21,
					'extension' => 'eps',
					'types' => 'application/eps application/postscript application/x-eps image/eps image/x-eps',
					'name' => 'Encapsulated PostScript',
					'dirname' => '',
				],
				[
					'mimetypeid' => 22,
					'extension' => 'ps',
					'types' => 'application/postscript application/ps application/x-postscript application/x-ps text/postscript',
					'name' => 'PostScript',
					'dirname' => '',
				],
				[
					'mimetypeid' => 23,
					'extension' => 'smi',
					'types' => 'application/smil',
					'name' => 'SMIL Multimedia',
					'dirname' => '',
				],
				[
					'mimetypeid' => 24,
					'extension' => 'smil',
					'types' => 'application/smil',
					'name' => 'Synchronized Multimedia Integration Language',
					'dirname' => '',
				],
				[
					'mimetypeid' => 25,
					'extension' => 'wmlc',
					'types' => 'application/vnd.wap.wmlc ',
					'name' => 'Compiled WML Document',
					'dirname' => '',
				],
				[
					'mimetypeid' => 26,
					'extension' => 'wmlsc',
					'types' => 'application/vnd.wap.wmlscriptc',
					'name' => 'Compiled WML Script',
					'dirname' => '',
				],
				[
					'mimetypeid' => 27,
					'extension' => 'vcd',
					'types' => 'application/x-cdlink',
					'name' => 'Virtual CD-ROM CD Image File',
					'dirname' => '',
				],
				[
					'mimetypeid' => 28,
					'extension' => 'pgn',
					'types' => 'application/formstore',
					'name' => 'Picatinny Arsenal Electronic Formstore Form in TIFF Format',
					'dirname' => '',
				],
				[
					'mimetypeid' => 29,
					'extension' => 'cpio',
					'types' => 'application/x-cpio',
					'name' => 'UNIX CPIO Archive',
					'dirname' => '',
				],
				[
					'mimetypeid' => 30,
					'extension' => 'csh',
					'types' => 'application/x-csh',
					'name' => 'Csh Script',
					'dirname' => '',
				],
				[
					'mimetypeid' => 31,
					'extension' => 'dcr',
					'types' => 'application/x-director',
					'name' => 'Shockwave Movie',
					'dirname' => '',
				],
				[
					'mimetypeid' => 32,
					'extension' => 'dir',
					'types' => 'application/x-director',
					'name' => 'Macromedia Director Movie',
					'dirname' => '',
				],
				[
					'mimetypeid' => 33,
					'extension' => 'dxr',
					'types' => 'application/x-director application/vnd.dxr',
					'name' => 'Macromedia Director Protected Movie File',
					'dirname' => '',
				],
				[
					'mimetypeid' => 34,
					'extension' => 'dvi',
					'types' => 'application/x-dvi',
					'name' => 'TeX Device Independent Document',
					'dirname' => '',
				],
				[
					'mimetypeid' => 35,
					'extension' => 'spl',
					'types' => 'application/x-futuresplash',
					'name' => 'Macromedia FutureSplash File',
					'dirname' => '',
				],
				[
					'mimetypeid' => 36,
					'extension' => 'hdf',
					'types' => 'application/x-hdf',
					'name' => 'Hierarchical Data Format File',
					'dirname' => '',
				],
				[
					'mimetypeid' => 37,
					'extension' => 'js',
					'types' => 'application/x-javascript text/javascript',
					'name' => 'JavaScript Source Code',
					'dirname' => '',
				],
				[
					'mimetypeid' => 38,
					'extension' => 'skp',
					'types' => 'application/x-koan application/vnd-koan koan/x-skm application/vnd.koan',
					'name' => 'SSEYO Koan Play File',
					'dirname' => '',
				],
				[
					'mimetypeid' => 39,
					'extension' => 'skd',
					'types' => 'application/x-koan application/vnd-koan koan/x-skm application/vnd.koan',
					'name' => 'SSEYO Koan Design File',
					'dirname' => '',
				],
				[
					'mimetypeid' => 40,
					'extension' => 'skt',
					'types' => 'application/x-koan application/vnd-koan koan/x-skm application/vnd.koan',
					'name' => 'SSEYO Koan Template File',
					'dirname' => '',
				],
				[
					'mimetypeid' => 41,
					'extension' => 'skm',
					'types' => 'application/x-koan application/vnd-koan koan/x-skm application/vnd.koan',
					'name' => 'SSEYO Koan Mix File',
					'dirname' => '',
				],
				[
					'mimetypeid' => 42,
					'extension' => 'latex',
					'types' => 'application/x-latex text/x-latex',
					'name' => 'LaTeX Source Document',
					'dirname' => '',
				],
				[
					'mimetypeid' => 43,
					'extension' => 'nc',
					'types' => 'application/x-netcdf text/x-cdf',
					'name' => 'Unidata netCDF Graphics',
					'dirname' => '',
				],
				[
					'mimetypeid' => 44,
					'extension' => 'cdf',
					'types' => 'application/cdf application/x-cdf application/netcdf application/x-netcdf text/cdf text/x-cdf',
					'name' => 'Channel Definition Format',
					'dirname' => '',
				],
				[
					'mimetypeid' => 45,
					'extension' => 'swf',
					'types' => 'application/x-shockwave-flash application/x-shockwave-flash2-preview application/futuresplash image/vnd.rn-realflash',
					'name' => 'Macromedia Flash Format File',
					'dirname' => '',
				],
				[
					'mimetypeid' => 46,
					'extension' => 'sit',
					'types' => 'application/stuffit application/x-stuffit application/x-sit',
					'name' => 'StuffIt Compressed Archive File',
					'dirname' => '',
				],
				[
					'mimetypeid' => 47,
					'extension' => 'tcl',
					'types' => 'application/x-tcl',
					'name' => 'TCL/TK Language Script',
					'dirname' => '',
				],
				[
					'mimetypeid' => 48,
					'extension' => 'tex',
					'types' => 'application/x-tex',
					'name' => 'LaTeX Source',
					'dirname' => '',
				],
				[
					'mimetypeid' => 49,
					'extension' => 'texinfo',
					'types' => 'application/x-texinfo',
					'name' => 'TeX',
					'dirname' => '',
				],
				[
					'mimetypeid' => 50,
					'extension' => 'texi',
					'types' => 'application/x-texinfo',
					'name' => 'TeX',
					'dirname' => '',
				],
				[
					'mimetypeid' => 51,
					'extension' => 't',
					'types' => 'application/x-troff',
					'name' => 'TAR Tape Archive Without Compression',
					'dirname' => '',
				],
				[
					'mimetypeid' => 52,
					'extension' => 'tr',
					'types' => 'application/x-troff',
					'name' => 'Unix Tape Archive = TAR without compression (tar)',
					'dirname' => '',
				],
				[
					'mimetypeid' => 53,
					'extension' => 'src',
					'types' => 'application/x-wais-source',
					'name' => 'Sourcecode',
					'dirname' => '',
				],
				[
					'mimetypeid' => 54,
					'extension' => 'xhtml',
					'types' => 'application/xhtml+xml',
					'name' => 'Extensible HyperText Markup Language File',
					'dirname' => '',
				],
				[
					'mimetypeid' => 55,
					'extension' => 'xht',
					'types' => 'application/xhtml+xml',
					'name' => 'Extensible HyperText Markup Language File',
					'dirname' => '',
				],
				[
					'mimetypeid' => 56,
					'extension' => 'au',
					'types' => 'audio/basic audio/x-basic audio/au audio/x-au audio/x-pn-au audio/rmf audio/x-rmf audio/x-ulaw audio/vnd.qcelp audio/x-gsm audio/snd',
					'name' => 'ULaw/AU Audio File',
					'dirname' => '',
				],
				[
					'mimetypeid' => 57,
					'extension' => 'XM',
					'types' => 'audio/xm audio/x-xm audio/module-xm audio/mod audio/x-mod',
					'name' => 'Fast Tracker 2 Extended Module',
					'dirname' => '',
				],
				[
					'mimetypeid' => 58,
					'extension' => 'snd',
					'types' => 'audio/basic',
					'name' => 'Macintosh Sound Resource',
					'dirname' => '',
				],
				[
					'mimetypeid' => 59,
					'extension' => 'mid',
					'types' => 'audio/mid audio/m audio/midi audio/x-midi application/x-midi audio/soundtrack',
					'name' => 'Musical Instrument Digital Interface MIDI-sequention Sound',
					'dirname' => '',
				],
				[
					'mimetypeid' => 60,
					'extension' => 'midi',
					'types' => 'audio/mid audio/m audio/midi audio/x-midi application/x-midi',
					'name' => 'Musical Instrument Digital Interface MIDI-sequention Sound',
					'dirname' => '',
				],
				[
					'mimetypeid' => 61,
					'extension' => 'kar',
					'types' => 'audio/midi audio/x-midi audio/mid x-music/x-midi',
					'name' => 'Karaoke MIDI File',
					'dirname' => '',
				],
				[
					'mimetypeid' => 62,
					'extension' => 'mpga',
					'types' => 'audio/mpeg audio/mp3 audio/mgp audio/m-mpeg audio/x-mp3 audio/x-mpeg audio/x-mpg video/mpeg',
					'name' => 'Mpeg-1 Layer3 Audio Stream',
					'dirname' => '',
				],
				[
					'mimetypeid' => 63,
					'extension' => 'mp2',
					'types' => 'video/mpeg audio/mpeg',
					'name' => 'MPEG Audio Stream, Layer II',
					'dirname' => '',
				],
				[
					'mimetypeid' => 64,
					'extension' => 'mp3',
					'types' => 'audio/mpeg audio/x-mpeg audio/mp3 audio/x-mp3 audio/mpeg3 audio/x-mpeg3 audio/mpg audio/x-mpg audio/x-mpegaudio',
					'name' => 'MPEG Audio Stream, Layer III',
					'dirname' => '',
				],
				[
					'mimetypeid' => 65,
					'extension' => 'aif',
					'types' => 'audio/aiff audio/x-aiff sound/aiff audio/rmf audio/x-rmf audio/x-pn-aiff audio/x-gsm audio/x-midi audio/vnd.qcelp',
					'name' => 'Audio Interchange File',
					'dirname' => '',
				],
				[
					'mimetypeid' => 66,
					'extension' => 'aiff',
					'types' => 'audio/aiff audio/x-aiff sound/aiff audio/rmf audio/x-rmf audio/x-pn-aiff audio/x-gsm audio/mid audio/x-midi audio/vnd.qcelp',
					'name' => 'Audio Interchange File',
					'dirname' => '',
				],
				[
					'mimetypeid' => 67,
					'extension' => 'aifc',
					'types' => 'audio/aiff audio/x-aiff audio/x-aifc sound/aiff audio/rmf audio/x-rmf audio/x-pn-aiff audio/x-gsm audio/x-midi audio/mid audio/vnd.qcelp',
					'name' => 'Audio Interchange File',
					'dirname' => '',
				],
				[
					'mimetypeid' => 68,
					'extension' => 'm3u',
					'types' => 'audio/x-mpegurl audio/mpeg-url application/x-winamp-playlist audio/scpls audio/x-scpls',
					'name' => 'MP3 Playlist File',
					'dirname' => '',
				],
				[
					'mimetypeid' => 69,
					'extension' => 'ram',
					'types' => 'audio/x-pn-realaudio audio/vnd.rn-realaudio audio/x-pm-realaudio-plugin audio/x-pn-realvideo audio/x-realaudio video/x-pn-realvideo text/plain',
					'name' => 'RealMedia Metafile',
					'dirname' => '',
				],
				[
					'mimetypeid' => 70,
					'extension' => 'rm',
					'types' => 'application/vnd.rn-realmedia audio/vnd.rn-realaudio audio/x-pn-realaudio audio/x-realaudio audio/x-pm-realaudio-plugin',
					'name' => 'RealMedia Streaming Media',
					'dirname' => '',
				],
				[
					'mimetypeid' => 71,
					'extension' => 'rpm',
					'types' => 'audio/x-pn-realaudio audio/x-pn-realaudio-plugin audio/x-pnrealaudio-plugin video/x-pn-realvideo-plugin audio/x-mpegurl application/octet-stream',
					'name' => 'RealMedia Player Plug-in',
					'dirname' => '',
				],
				[
					'mimetypeid' => 72,
					'extension' => 'ra',
					'types' => 'audio/vnd.rn-realaudio audio/x-pn-realaudio audio/x-realaudio audio/x-pm-realaudio-plugin video/x-pn-realvideo',
					'name' => 'RealMedia Streaming Media',
					'dirname' => '',
				],
				[
					'mimetypeid' => 73,
					'extension' => 'wav',
					'types' => 'audio/wav audio/x-wav audio/wave audio/x-pn-wav',
					'name' => 'Waveform Audio',
					'dirname' => '',
				],
				[
					'mimetypeid' => 74,
					'extension' => 'wax',
					'types' => ' audio/x-ms-wax',
					'name' => 'Windows Media Audio Redirector',
					'dirname' => '',
				],
				[
					'mimetypeid' => 75,
					'extension' => 'wma',
					'types' => 'audio/x-ms-wma video/x-ms-asf',
					'name' => 'Windows Media Audio File',
					'dirname' => '',
				],
				[
					'mimetypeid' => 76,
					'extension' => 'bmp',
					'types' => 'image/bmp image/x-bmp image/x-bitmap image/x-xbitmap image/x-win-bitmap image/x-windows-bmp image/ms-bmp image/x-ms-bmp application/bmp application/x-bmp application/x-win-bitmap application/preview',
					'name' => 'Windows OS/2 Bitmap Graphics',
					'dirname' => 'system',
				],
				[
					'mimetypeid' => 77,
					'extension' => 'gif',
					'types' => 'image/gif image/x-xbitmap image/gi_',
					'name' => 'Graphic Interchange Format',
					'dirname' => 'system',
				],
				[
					'mimetypeid' => 78,
					'extension' => 'ief',
					'types' => 'image/ief',
					'name' => 'Image File - Bitmap graphics',
					'dirname' => '',
				],
				[
					'mimetypeid' => 79,
					'extension' => 'jpeg',
					'types' => 'image/jpeg image/jpg image/jpe_ image/pjpeg image/vnd.swiftview-jpeg',
					'name' => 'JPEG/JIFF Image',
					'dirname' => 'system',
				],
				[
					'mimetypeid' => 80,
					'extension' => 'jpg',
					'types' => 'image/jpeg image/jpg image/jp_ application/jpg application/x-jpg image/pjpeg image/pipeg image/vnd.swiftview-jpeg image/x-xbitmap',
					'name' => 'JPEG/JIFF Image',
					'dirname' => 'system',
				],
				[
					'mimetypeid' => 81,
					'extension' => 'jpe',
					'types' => 'image/jpeg',
					'name' => 'JPEG/JIFF Image',
					'dirname' => 'system',
				],
				[
					'mimetypeid' => 82,
					'extension' => 'png',
					'types' => 'image/png application/png application/x-png',
					'name' => 'Portable (Public) Network Graphic',
					'dirname' => 'system',
				],
				[
					'mimetypeid' => 83,
					'extension' => 'tiff',
					'types' => 'image/tiff',
					'name' => 'Tagged Image Format File',
					'dirname' => 'system',
				],
				[
					'mimetypeid' => 84,
					'extension' => 'tif',
					'types' => 'image/tif image/x-tif image/tiff image/x-tiff application/tif application/x-tif application/tiff application/x-tiff',
					'name' => 'Tagged Image Format File',
					'dirname' => 'system',
				],
				[
					'mimetypeid' => 85,
					'extension' => 'ico',
					'types' => 'image/ico image/x-icon application/ico application/x-ico application/x-win-bitmap image/x-win-bitmap application/octet-stream',
					'name' => 'Windows Icon',
					'dirname' => '',
				],
				[
					'mimetypeid' => 86,
					'extension' => 'wbmp',
					'types' => 'image/vnd.wap.wbmp',
					'name' => 'Wireless Bitmap File Format',
					'dirname' => '',
				],
				[
					'mimetypeid' => 87,
					'extension' => 'ras',
					'types' => 'application/ras application/x-ras image/ras',
					'name' => 'Sun Raster Graphic',
					'dirname' => '',
				],
				[
					'mimetypeid' => 88,
					'extension' => 'pnm',
					'types' => 'image/x-portable-anymap',
					'name' => 'PBM Portable Any Map Graphic Bitmap',
					'dirname' => '',
				],
				[
					'mimetypeid' => 89,
					'extension' => 'pbm',
					'types' => 'image/portable bitmap image/x-portable-bitmap image/pbm image/x-pbm',
					'name' => 'UNIX Portable Bitmap Graphic',
					'dirname' => '',
				],
				[
					'mimetypeid' => 90,
					'extension' => 'pgm',
					'types' => 'image/x-portable-graymap image/x-pgm',
					'name' => 'Portable Graymap Graphic',
					'dirname' => '',
				],
				[
					'mimetypeid' => 91,
					'extension' => 'ppm',
					'types' => 'image/x-portable-pixmap application/ppm application/x-ppm image/x-p image/x-ppm',
					'name' => 'PBM Portable Pixelmap Graphic',
					'dirname' => '',
				],
				[
					'mimetypeid' => 92,
					'extension' => 'rgb',
					'types' => 'image/rgb image/x-rgb',
					'name' => 'Silicon Graphics RGB Bitmap',
					'dirname' => '',
				],
				[
					'mimetypeid' => 93,
					'extension' => 'xbm',
					'types' => 'image/x-xpixmap image/x-xbitmap image/xpm image/x-xpm',
					'name' => 'X Bitmap Graphic',
					'dirname' => '',
				],
				[
					'mimetypeid' => 94,
					'extension' => 'xpm',
					'types' => 'image/x-xpixmap',
					'name' => 'BMC Software Patrol UNIX Icon File',
					'dirname' => '',
				],
				[
					'mimetypeid' => 95,
					'extension' => 'xwd',
					'types' => 'image/x-xwindowdump image/xwd image/x-xwd application/xwd application/x-xwd',
					'name' => 'X Windows Dump',
					'dirname' => '',
				],
				[
					'mimetypeid' => 96,
					'extension' => 'igs',
					'types' => 'model/iges application/iges application/x-iges application/igs application/x-igs drawing/x-igs image/x-igs',
					'name' => 'Initial Graphics Exchange Specification Format',
					'dirname' => '',
				],
				[
					'mimetypeid' => 97,
					'extension' => 'css',
					'types' => 'application/css-stylesheet text/css',
					'name' => 'Hypertext Cascading Style Sheet',
					'dirname' => '',
				],
				[
					'mimetypeid' => 98,
					'extension' => 'html',
					'types' => 'text/html text/plain',
					'name' => 'Hypertext Markup Language',
					'dirname' => '',
				],
				[
					'mimetypeid' => 99,
					'extension' => 'htm',
					'types' => 'text/html',
					'name' => 'Hypertext Markup Language',
					'dirname' => '',
				],
				[
					'mimetypeid' => 100,
					'extension' => 'txt',
					'types' => 'text/plain application/txt browser/internal',
					'name' => 'Text File',
					'dirname' => 'system',
				],
				[
					'mimetypeid' => 101,
					'extension' => 'rtf',
					'types' => 'application/rtf application/x-rtf text/rtf text/richtext application/msword application/doc application/x-soffice',
					'name' => 'Rich Text Format File',
					'dirname' => 'system',
				],
				[
					'mimetypeid' => 102,
					'extension' => 'wml',
					'types' => 'text/vnd.wap.wml text/wml',
					'name' => 'Website META Language File',
					'dirname' => '',
				],
				[
					'mimetypeid' => 103,
					'extension' => 'wmls',
					'types' => 'text/vnd.wap.wmlscript',
					'name' => 'WML Script',
					'dirname' => '',
				],
				[
					'mimetypeid' => 104,
					'extension' => 'etx',
					'types' => 'text/x-setext',
					'name' => 'SetText Structure Enhanced Text',
					'dirname' => '',
				],
				[
					'mimetypeid' => 105,
					'extension' => 'xml',
					'types' => 'text/xml application/xml application/x-xml',
					'name' => 'Extensible Markup Language File',
					'dirname' => '',
				],
				[
					'mimetypeid' => 106,
					'extension' => 'xsl',
					'types' => 'text/xml',
					'name' => 'XML Stylesheet',
					'dirname' => '',
				],
				[
					'mimetypeid' => 107,
					'extension' => 'php',
					'types' => 'text/php application/x-httpd-php application/php magnus-internal/shellcgi application/x-php',
					'name' => 'PHP Script',
					'dirname' => '',
				],
				[
					'mimetypeid' => 108,
					'extension' => 'php3',
					'types' => 'text/php3 application/x-httpd-php',
					'name' => 'PHP Script',
					'dirname' => '',
				],
				[
					'mimetypeid' => 109,
					'extension' => 'mpeg',
					'types' => 'video/mpeg',
					'name' => 'MPEG Movie',
					'dirname' => '',
				],
				[
					'mimetypeid' => 110,
					'extension' => 'mpg',
					'types' => 'video/mpeg video/mpg video/x-mpg video/mpeg2 application/x-pn-mpg video/x-mpeg video/x-mpeg2a audio/mpeg audio/x-mpeg image/mpg',
					'name' => 'MPEG 1 System Stream',
					'dirname' => '',
				],
				[
					'mimetypeid' => 111,
					'extension' => 'mpe',
					'types' => 'video/mpeg',
					'name' => 'MPEG Movie Clip',
					'dirname' => '',
				],
				[
					'mimetypeid' => 112,
					'extension' => 'qt',
					'types' => 'video/quicktime audio/aiff audio/x-wav video/flc',
					'name' => 'QuickTime Movie',
					'dirname' => '',
				],
				[
					'mimetypeid' => 113,
					'extension' => 'mov',
					'types' => 'video/quicktime video/x-quicktime image/mov audio/aiff audio/x-midi audio/x-wav video/avi',
					'name' => 'QuickTime Video Clip',
					'dirname' => '',
				],
				[
					'mimetypeid' => 114,
					'extension' => 'avi',
					'types' => 'video/avi video/msvideo video/x-msvideo image/avi video/xmpg2 application/x-troff-msvideo audio/aiff audio/avi',
					'name' => 'Audio Video Interleave File',
					'dirname' => '',
				],
				[
					'mimetypeid' => 115,
					'extension' => 'movie',
					'types' => 'video/sgi-movie video/x-sgi-movie',
					'name' => 'QuickTime Movie',
					'dirname' => '',
				],
				[
					'mimetypeid' => 116,
					'extension' => 'asf',
					'types' => 'audio/asf application/asx video/x-ms-asf-plugin application/x-mplayer2 video/x-ms-asf application/vnd.ms-asf video/x-ms-asf-plugin video/x-ms-wm video/x-ms-wmx',
					'name' => 'Advanced Streaming Format',
					'dirname' => '',
				],
				[
					'mimetypeid' => 117,
					'extension' => 'asx',
					'types' => 'video/asx application/asx video/x-ms-asf-plugin application/x-mplayer2 video/x-ms-asf application/vnd.ms-asf video/x-ms-asf-plugin video/x-ms-wm video/x-ms-wmx video/x-la-asf',
					'name' => 'Advanced Stream Redirector File',
					'dirname' => '',
				],
				[
					'mimetypeid' => 118,
					'extension' => 'wmv',
					'types' => 'video/x-ms-wmv',
					'name' => 'Windows Media File',
					'dirname' => '',
				],
				[
					'mimetypeid' => 119,
					'extension' => 'wvx',
					'types' => 'video/x-ms-wvx',
					'name' => 'Windows Media Redirector',
					'dirname' => '',
				],
				[
					'mimetypeid' => 120,
					'extension' => 'wm',
					'types' => 'video/x-ms-wm',
					'name' => 'Windows Media A/V File',
					'dirname' => '',
				],
				[
					'mimetypeid' => 121,
					'extension' => 'wmx',
					'types' => 'video/x-ms-wmx',
					'name' => 'Windows Media Player A/V Shortcut',
					'dirname' => '',
				],
				[
					'mimetypeid' => 122,
					'extension' => 'ice',
					'types' => 'x-conference-xcooltalk',
					'name' => 'Cooltalk Audio',
					'dirname' => '',
				],
				[
					'mimetypeid' => 123,
					'extension' => 'rar',
					'types' => 'application/octet-stream',
					'name' => 'WinRAR Compressed Archive',
					'dirname' => '',
				],
			]);
	}

	/**
	 * Prefix table
	 *
	 * @param string $table Table to prefix
	 *
	 * @return string
	 */
	private function prefix(string $table): string
	{
		return \icms::getInstance()->get('db-connection-1')->prefix($table);
	}
}
